@@ -1,5 +1,5 @@
 package Acme::CPANAuthors::POE;
-$Acme::CPANAuthors::POE::VERSION = '0.80';
+$Acme::CPANAuthors::POE::VERSION = '0.82';
 #ABSTRACT: We are CPAN Authors of POE
 
 use strict;
@@ -14,7 +14,7 @@ use Acme::CPANAuthors::Register (
   AHOYING => q[Andrew Hoying],
   AIMASS => q[Alejandro Imass],
   AJCT => q[Adam Taylor],
-  ALTREUS => q[Alastair Douglas],
+  ALTREUS => q[Alastair McGowan-Douglas],
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
@@ -177,7 +177,7 @@ Acme::CPANAuthors::POE - We are CPAN Authors of POE
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -208,7 +208,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   AHOYING => q[Andrew Hoying],
   AIMASS => q[Alejandro Imass],
   AJCT => q[Adam Taylor],
-  ALTREUS => q[Alastair Douglas],
+  ALTREUS => q[Alastair McGowan-Douglas],
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
